import { BaseGameDataMessage } from "@skeldjs/protocol";
import { CustomNetworkTransform, CustomNetworkTransformEvents, PlayerControl, PlayerControlEvents, PlayerPhysics, PlayerPhysicsEvents } from "./objects";
import { Heritable, HeritableEvents } from "./Heritable";
import { Hostable } from "./Hostable";
import { PlayerJoinEvent, PlayerLeaveEvent, PlayerReadyEvent, PlayerSceneChangeEvent, PlayerSetHostEvent, PlayerSpawnEvent } from "./events";
import { ExtractEventTypes } from "@skeldjs/events";
export declare type PlayerDataEvents<RoomType extends Hostable = Hostable> = HeritableEvents<RoomType> & PlayerControlEvents<RoomType> & PlayerPhysicsEvents<RoomType> & CustomNetworkTransformEvents<RoomType> & ExtractEventTypes<[
    PlayerReadyEvent<RoomType>,
    PlayerJoinEvent<RoomType>,
    PlayerLeaveEvent<RoomType>,
    PlayerSetHostEvent<RoomType>,
    PlayerSceneChangeEvent<RoomType>,
    PlayerSpawnEvent<RoomType>
]>;
/**
 * Represents the player of a client connected to the room.
 *
 * See {@link PlayerDataEvents} for events to listen to.
 */
export declare class PlayerData<RoomType extends Hostable = Hostable> extends Heritable<PlayerDataEvents<RoomType>, RoomType> {
    /**
     * Whether or not this player is readied up to start the game.
     */
    isReady: boolean;
    /**
     * Whether or not this player is in the game scene.
     */
    inScene: boolean;
    /**
     * Whether or not this player has left the game.
     */
    left: boolean;
    /**
     * The message stream to be sent on fixed update.
     */
    stream: BaseGameDataMessage[];
    character: PlayerControl<RoomType> | undefined;
    constructor(room: RoomType, clientid: number);
    /**
     * The player's control component.
     */
    get control(): PlayerControl<RoomType> | undefined;
    /**
     * The player's physics component.
     */
    get physics(): PlayerPhysics<RoomType> | undefined;
    /**
     * The player's movement component.
     */
    get transform(): CustomNetworkTransform<RoomType>;
    /**
     * The player's information.
     */
    get info(): import(".").PlayerInfo<RoomType> | undefined;
    /**
     * The player ID of the player.
     */
    get playerId(): number | undefined;
    /**
     * Whether or not the player has fully spawned.
     */
    get spawned(): boolean;
    /**
     * Whether or not the player is the host of the room they belong in.
     */
    get ishost(): boolean;
    /**
     * Whether or not the player is the current client's player.
     */
    get isme(): boolean;
    /**
     * Mark as readied up to start the game.
     */
    ready(): Promise<void>;
}
